@@ -283,10 +283,8 @@ nextopt:
 		argc--, argv++;
 	}
 	(void) freopen("/dev/null", "w", stderr);
-	(void) signal(SIGPIPE, lostconn);
 	(void) signal(SIGCHLD, SIG_IGN);
-	if ((int)signal(SIGURG, myoob) < 0)
-		syslog(LOG_ERR, "signal: %m");
+	enable_signalling();
 
 	/* avoid core dumps with cleartext or (shadow) passwords. */
 #ifdef RLIMIT_CORE
@@ -323,6 +321,20 @@ nextopt:
 	/* NOTREACHED */
 }
 
+enable_signalling()
+{
+	(void) signal(SIGPIPE, lostconn);
+	if ((int)signal(SIGURG, myoob) < 0)
+		syslog(LOG_ERR, "signal: %m");
+}
+
+disable_signalling()
+{
+	(void) signal(SIGPIPE, SIG_IGN);
+	if ((int)signal(SIGURG, SIG_IGN) < 0)
+		syslog(LOG_ERR, "signal: %m");
+}
+
 void
 lostconn()
 {
@@ -492,12 +504,14 @@ user(name)
 end_login()
 {
 
+	disable_signalling();
 	(void) seteuid((uid_t)0);
 	if (logged_in)
 		logwtmp(ttyline, "", "");
 	pw = NULL;
 	logged_in = 0;
 	guest = 0;
+	enable_signalling();
 }
 
 pass(passwd)
@@ -723,6 +737,7 @@ getdatasock(mode)
 
 	if (data >= 0)
 		return (fdopen(data, mode));
+	disable_signalling();
 	(void) seteuid((uid_t)0);
 	s = socket(AF_INET, SOCK_STREAM, 0);
 	if (s < 0)
@@ -740,11 +755,13 @@ getdatasock(mode)
 		goto bad;
 	}
 	(void) seteuid((uid_t)pw->pw_uid);
+	enable_signalling();
 	return (fdopen(s, mode));
 bad:
 	(void) close(s);
 bad2:
 	(void) seteuid((uid_t)pw->pw_uid);
+	enable_signalling();
 	return (NULL);
 }
 
@@ -1257,6 +1274,7 @@ dolog(sin)
 dologout(status)
 	int status;
 {
+	disable_signalling();
 	if (logged_in) {
 		(void) seteuid((uid_t)0);
 		logwtmp(ttyline, "", "");
