@@ -323,12 +323,23 @@ ruserok(rhost, superuser, ruser, luser)
 		 * if owned by someone other than user or root or if
 		 * writeable by anyone but the owner, quit
 		 */
-		if (fstat(fileno(hostf), &sbuf) ||
-		    (sbuf.st_uid && sbuf.st_uid != pwd->pw_uid) ||
-		    sbuf.st_mode&022) {
+		if (fstat(fileno(hostf), &sbuf) != 0) {
+			syslog(LOG_ERR, "fstat(%s): %m", pbuf);
 			fclose(hostf);
 			restore_and_return(-1);
 		}
+		if (sbuf.st_uid && sbuf.st_uid != pwd->pw_uid) {
+			fclose(hostf);
+			syslog(LOG_ALERT, "%s: illegal owner uid %d",
+				pbuf, sbuf.st_uid);
+			restore_and_return(-1);
+		}
+		if (sbuf.st_mode & 022) {
+			fclose(hostf);
+			syslog(LOG_ALERT, "%s: illegal permission %3o",
+				pbuf, sbuf.st_mode & 0777);
+			restore_and_return(-1);
+		}
 		if (!_validuser(hostf, fhost, luser, ruser, baselen)) {
 			(void) fclose(hostf);
 			restore_and_return(0);
