@@ -58,6 +58,12 @@ static char sccsid[] = "@(#)login.c	5.32.1.1 (Berkeley) 1/28/89";
 #define UT_NAMESIZE	sizeof(((struct UTMP_STRUCT *)0)->ut_name)
 #endif /* UT_NAMESIZE */
 
+#ifdef HPUX10_TRUSTED
+#include <sys/types.h>
+#include <hpsecurity.h>
+#include <prot.h>
+#endif
+
 #ifdef DECOSF1_ENHANCED
 #include <sys/types.h>
 #include <sys/security.h>
@@ -218,7 +224,7 @@ main(argc, argv)
 	int mask;
 	int maxtrys;
 #endif /* SYSV_LOGINDEFS */
-#ifdef DECOSF1_ENHANCED
+#if defined(DECOSF1_ENHANCED) || defined(HPUX10_TRUSTED)
 	struct pr_passwd *pr;
 	(void) set_auth_parameters(argc, argv);
 #endif
@@ -440,11 +446,17 @@ main(argc, argv)
 				badlogin(tbuf);
 			failures = 0;
 		}
-		(void)strcpy(tbuf, username);
+
+		/*
+		 * Work around a buffer overflow opportunity that dates all
+		 * the way back to 4.4+ BSD, and perhaps even earlier.
+		 */
+		(void)strncpy(tbuf, username, sizeof(tbuf) - 1);
+		tbuf[sizeof(tbuf) - 1] = 0;
 		if (pwd = getpwnam(username))
-#ifdef DECOSF1_ENHANCED
+#if defined(DECOSF1_ENHANCED) || defined(HPUX10_TRUSTED)
 		{
-			if (pr = getprpwnam(username)) {
+			if ((pr = getprpwnam(username)) && pr->ufld.fd_encrypt) {
 				pwd->pw_passwd = strdup(pr->ufld.fd_encrypt);
 				salt = pwd->pw_passwd;
 			} else {
