@@ -436,12 +436,12 @@ char   *host;
 
     for (i = 0; i < MAX_ADDR && hp->h_addr_list[i]; i++)
 	memcpy((char *) &list[i],
-	       hp->h_addr_list[i], hp->h_length);
+	       hp->h_addr_list[i], sizeof(*list));
     list[i].s_addr = 0;
 
     strncpy(buf, hp->h_name, MAXHOSTNAMELEN);
     buf[MAXHOSTNAMELEN] = 0;
-    length = hp->h_length;
+    length = sizeof(*list);
 
     /*
      * Wipe addresses that appear to belong to someone else. We will get
