@@ -150,8 +150,8 @@ int	not42 = 1;
 #define	BANNER  "\r\n\r\nHP-UX %s\r\n\r\r\n\r"
 #endif
 
-#ifdef OSF1
-#define BANNER	"\r\n\r\nOSF/1 %s\r\n\r\r\n\r"
+#ifdef DECOSF1
+#define BANNER	"\r\n\r\Digital UNIX (%s)\r\n\r\r\n\r"
 #endif
 
 #ifndef BANNER
@@ -741,9 +741,11 @@ telnet(f, p)
 		}
 		if (ptyibuf[0] & TIOCPKT_FLUSHWRITE) {
 			netclear();	/* clear buffer back */
+#ifndef BROKEN_OOB
 			*nfrontp++ = IAC;
 			*nfrontp++ = DM;
 			neturg = nfrontp-1;  /* off by one XXX */
+#endif
 			ptyibuf[0] = 0;
 		}
 
